@@ -39,7 +39,9 @@
 MODULE_AUTHOR("Jouni Malinen");
 MODULE_DESCRIPTION("Host AP crypt: CCMP");
 MODULE_LICENSE("GPL");
-
+#ifdef MODULE_VERSION
+MODULE_VERSION(PRISM2_VERSION);
+#endif
 
 #define AES_BLOCK_LEN 16
 #define CCMP_HDR_LEN 8
