@@ -19,7 +19,9 @@
 #endif
 #include "hostap_wext.h"
 
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13))
 #include <pcmcia/version.h>
+#endif
 #include <pcmcia/cs_types.h>
 #include <pcmcia/cs.h>
 #include <pcmcia/cistpl.h>
@@ -50,11 +52,13 @@ MODULE_VERSION(PRISM2_VERSION);
 #endif
 
 
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13))
 static unsigned int irq_mask = 0xdeb8;
 MODULE_PARM(irq_mask, "i");
 
 static int irq_list[4] = { -1 };
 MODULE_PARM(irq_list, "1-4i");
+#endif
 
 static int ignore_cis_vcc = 0;
 MODULE_PARM(ignore_cis_vcc, "i");
@@ -527,12 +531,14 @@ static dev_link_t *prism2_attach(void)
 	link->next = dev_list;
 	dev_list = link;
 	client_reg.dev_info = &dev_info;
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,13))
 	client_reg.Attributes = INFO_IO_CLIENT;
 	client_reg.EventMask = CS_EVENT_CARD_INSERTION |
 		CS_EVENT_CARD_REMOVAL |
 		CS_EVENT_RESET_PHYSICAL | CS_EVENT_CARD_RESET |
 		CS_EVENT_PM_SUSPEND | CS_EVENT_PM_RESUME;
 	client_reg.event_handler = &prism2_event;
+#endif
 	client_reg.Version = 0x0210;
 	client_reg.event_callback_args.client_data = link;
 	ret = pcmcia_register_client(&link->handle, &client_reg);
@@ -728,17 +734,33 @@ static int prism2_config(dev_link_t *link)
 	}
 
 	/* Need to allocate net_device before requesting IRQ handler */
-	dev = prism2_init_local_data(&prism2_pccard_funcs, 0);
+	dev = prism2_init_local_data(&prism2_pccard_funcs, 0,
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,11))
+				     NULL
+#else
+				     &handle_to_dev(link->handle)
+#endif
+		);
 	if (dev == NULL)
 		goto failed;
 	link->priv = dev;
 
+	iface = dev->priv;
+	local = iface->local;
+	local->link = link;
+	strcpy(local->node.dev_name, dev->name);
+	link->dev = &local->node;
+
 	/*
 	 * Allocate an interrupt line.  Note that this does not assign a
 	 * handler to the interrupt, unless the 'Handler' member of the
 	 * irq structure is initialized.
 	 */
 	if (link->conf.Attributes & CONF_ENABLE_IRQ) {
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,13))
+		link->irq.Attributes = IRQ_TYPE_EXCLUSIVE | IRQ_HANDLE_PRESENT;
+		link->irq.IRQInfo1 = IRQ_LEVEL_ID;
+#else
 		int i;
 		link->irq.Attributes = IRQ_TYPE_EXCLUSIVE | IRQ_HANDLE_PRESENT;
 		link->irq.IRQInfo1 = IRQ_INFO2_VALID | IRQ_LEVEL_ID;
@@ -747,6 +769,7 @@ static int prism2_config(dev_link_t *link)
 		else
 			for (i = 0; i < 4; i++)
 				link->irq.IRQInfo2 |= 1 << irq_list[i];
+#endif
 		link->irq.Handler = prism2_interrupt;
 		link->irq.Instance = dev;
 		CS_CHECK(RequestIRQ,
@@ -784,12 +807,6 @@ static int prism2_config(dev_link_t *link)
 	link->state |= DEV_CONFIG;
 	link->state &= ~DEV_CONFIG_PENDING;
 
-	iface = dev->priv;
-	local = iface->local;
-	local->link = link;
-	strcpy(local->node.dev_name, dev->name);
-	link->dev = &local->node;
-
 	local->shutdown = 0;
 
 	sandisk_enable_wireless(dev);
@@ -910,6 +927,59 @@ static int prism2_event(event_t event, int priority,
 
 
 #if LINUX_VERSION_CODE > KERNEL_VERSION(2,5,67)
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,13))
+static struct pcmcia_device_id hostap_cs_ids[] = {
+	PCMCIA_DEVICE_MANF_CARD(0x000b, 0x7100),
+	PCMCIA_DEVICE_MANF_CARD(0x000b, 0x7300),
+	PCMCIA_DEVICE_MANF_CARD(0x0101, 0x0777),
+	PCMCIA_DEVICE_MANF_CARD(0x0126, 0x8000),
+	PCMCIA_DEVICE_MANF_CARD(0x0138, 0x0002),
+	PCMCIA_DEVICE_MANF_CARD(0x0156, 0x0002),
+	PCMCIA_DEVICE_MANF_CARD(0x0250, 0x0002),
+	PCMCIA_DEVICE_MANF_CARD(0x0274, 0x1612),
+	PCMCIA_DEVICE_MANF_CARD(0x0274, 0x1613),
+	PCMCIA_DEVICE_MANF_CARD(0x028a, 0x0002),
+	PCMCIA_DEVICE_MANF_CARD(0x02aa, 0x0002),
+	PCMCIA_DEVICE_MANF_CARD(0x02d2, 0x0001),
+	PCMCIA_DEVICE_MANF_CARD(0x1668, 0x0101),
+	PCMCIA_DEVICE_MANF_CARD(0x50c2, 0x0001),
+	PCMCIA_DEVICE_MANF_CARD(0x50c2, 0x7300),
+	PCMCIA_DEVICE_MANF_CARD(0xc00f, 0x0000),
+	PCMCIA_DEVICE_MANF_CARD(0xd601, 0x0002),
+	PCMCIA_DEVICE_MANF_CARD(0xd601, 0x0005),
+	PCMCIA_DEVICE_MANF_CARD(0xd601, 0x0010),
+	PCMCIA_MFC_DEVICE_PROD_ID12(0, "SanDisk", "ConnectPlus",
+				    0x7a954bd9, 0x74be00c6),
+	PCMCIA_DEVICE_PROD_ID1234(
+		"Intersil", "PRISM 2_5 PCMCIA ADAPTER",	"ISL37300P",
+		"Eval-RevA",
+		0x4b801a17, 0x6345a0bf, 0xc9049a39, 0xc23adc0e),
+	PCMCIA_DEVICE_PROD_ID123(
+		"Addtron", "AWP-100 Wireless PCMCIA", "Version 01.02",
+		0xe6ec52ce, 0x08649af2, 0x4b74baa0),
+	PCMCIA_DEVICE_PROD_ID123(
+		"D", "Link DWL-650 11Mbps WLAN Card", "Version 01.02",
+		0x71b18589, 0xb6f1b0ab, 0x4b74baa0),
+	PCMCIA_DEVICE_PROD_ID123(
+		"Instant Wireless ", " Network PC CARD", "Version 01.02",
+		0x11d901af, 0x6e9bd926, 0x4b74baa0),
+	PCMCIA_DEVICE_PROD_ID123(
+		"SMC", "SMC2632W", "Version 01.02",
+		0xc4f8b18b, 0x474a1f2a, 0x4b74baa0),
+	PCMCIA_DEVICE_PROD_ID12("Compaq", "WL200_11Mbps_Wireless_PCI_Card",
+				0x54f7c49c, 0x15a75e5b),
+	PCMCIA_DEVICE_PROD_ID12("INTERSIL", "HFA384x/IEEE",
+				0x74c5e40d, 0xdb472a18),
+	PCMCIA_DEVICE_PROD_ID12("Linksys", "Wireless CompactFlash Card",
+				0x0733cc81, 0x0c52f395),
+	PCMCIA_DEVICE_PROD_ID12(
+		"ZoomAir 11Mbps High", "Rate wireless Networking",
+		0x273fe3db, 0x32a1eaee),
+	PCMCIA_DEVICE_NULL
+};
+MODULE_DEVICE_TABLE(pcmcia, hostap_cs_ids);
+#endif /* >= 2.6.13 */
+
 static struct pcmcia_driver hostap_driver = {
 	.drv		= {
 		.name	= "hostap_cs",
@@ -917,6 +987,10 @@ static struct pcmcia_driver hostap_driver = {
 	.attach		= prism2_attach,
 	.detach		= prism2_detach,
 	.owner		= THIS_MODULE,
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,13))
+	.event		= prism2_event,
+	.id_table	= hostap_cs_ids,
+#endif
 };
 
 static int __init init_prism2_pccard(void)
