@@ -267,7 +267,13 @@ static int prism2_pci_probe(struct pci_dev *pdev,
 	pci_set_master(pdev);
 #endif /* PRISM2_BUS_MASTER */
 
-	dev = prism2_init_local_data(&prism2_pci_funcs, cards_found);
+	dev = prism2_init_local_data(&prism2_pci_funcs, cards_found,
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,6,0))
+				     NULL
+#else
+				     &pdev->dev
+#endif
+		);
 	if (dev == NULL)
 		goto fail;
 	iface = dev->priv;
@@ -388,7 +394,7 @@ static int prism2_pci_resume(struct pci_dev *pdev)
 MODULE_DEVICE_TABLE(pci, prism2_pci_id_table);
 
 static struct pci_driver prism2_pci_drv_id = {
-	.name		= "prism2_pci",
+	.name		= "hostap_pci",
 	.id_table	= prism2_pci_id_table,
 	.probe		= prism2_pci_probe,
 	.remove		= prism2_pci_remove,
