@@ -52,4 +52,15 @@
 #endif /* IW_PRIV_TYPE_ADDR */
 #endif /* PRISM2_USE_WE_TYPE_ADDR */
 
+#ifndef IW_QUAL_LEVEL_UPDATED
+#define IW_QUAL_LEVEL_UPDATED	0x02	/* Value was updated since last read */
+#define IW_QUAL_NOISE_UPDATED	0x04
+#define IW_QUAL_QUAL_INVALID	0x10	/* Driver doesn't provide value */
+#endif
+#ifndef IW_QUAL_ALL_UPDATED
+#define IW_QUAL_ALL_UPDATED	0x07	/* Value was updated since last read */
+#define IW_QUAL_DBM		0x08	/* Level + Noise are dBm */
+#define IW_QUAL_ALL_INVALID	0x70	/* Driver doesn't provide values */
+#endif
+
 #endif /* HOSTAP_WEXT_H */
